GSP_opts: A list of tibbles specifying the pedigrees available from...

GSP_optsR Documentation

A list of tibbles specifying the pedigrees available from createGSP()

Description

This is a list that is used by the function createGSP(). There are 15 different genomic simulation pedigrees, specified as tibbles, in this list.

Format

A list of 15 tibbles

Written by package authors Rachael and Tim


gscramble documentation built on July 3, 2026, 9:07 a.m.